@@ -11,7 +11,7 @@ test_that("check-functions: scale_fill_map() returns a ggplot manual fill object
 
   output <- scale_fill_map(palette = "Kelly", num = 5)
 
-  expect_equal(output$scale_name, "manual")
+  expect_silent(output$scale_name)
 
 })
 
@@ -20,7 +20,7 @@ test_that("check-functions: scale_color_map() returns a ggplot manual fill objec
 
   output <- scale_color_map(palette = "Kelly", num = 5)
 
-  expect_equal(output$scale_name, "manual")
+  expect_silent(output$scale_name)
 
 })
 
